@@ -16,21 +16,28 @@ INSERT INTO agent_versions (dev_type, version_major, version_minor, version_patc
 (4, 1, 0, 1, true);
 
 INSERT INTO product_versions (id, actual, version_major, version_minor, version_patchlevel, version_string, major, beta, notification, force_display, release_date, description) values 
-(1, true, 1, 0, 5, 'Party patch5', false, true, true, true, NOW(),
+(1, true, 1, 0, 6, 'Party patch6', false, false, true, true, '2026-02-20',
 '<h5>Release notes</h5>'
 '<h6>Server:</h6><ul>'
-'<li>Updated bundled license.</li>'
+'<li>Fix for no options in OS versions filter when no firmware version is available.</li>'
+'<li>Improved automatic deletion of invalid firmware versions.</li>'
+'<li>Backport: DBdump script (for debugging purposes).</li>'
+'<li>Backport: Dwarfg CMDline: dwarfg_datadump (DBdump script call).</li>'
+'<li>Backport: Dwarfg CMDline: dwarfg_user.</li>'
+'<li>Backport: Dwarfg CMDline general update.</li>'
+'<li>Updated free license.</li>'
 '</ul><h6>Agents:</h6><ul>'
+'<li>Prep for upgrade to 2.0.0: Use old DevID as preferred one when server requests re-registration.</li>'
 '</ul>');
 
-INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.4 (+3)');
+INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.6');
 INSERT INTO product_flags(id, version, description) values ('about_info', 1, 'Dwarfguard - Monitoring, Alerting, Management and Automation System
 
-Build tag: v1.0.4 (+3)
-Build date: 2025_09_15__11_26_01
+Build tag: v1.0.6
+Build date: 2026_02_28__19_56_34
 
 Build components:
-(mamas): v1.0.4 (+2)
-(mamasbig): v1.0.4 (+1)
-(mamasweb): v1.0.4
-(mamasnotify): v1.0.4');
+(mamas): v1.0.6
+(mamasbig): v1.0.6
+(mamasweb): v1.0.6
+(mamasnotify): v1.0.6');
